pub struct RenameEdits {
pub new_path: PathBuf,
pub new_stem: String,
pub id_will_update: bool,
pub backlink_edits: Vec<(PathBuf, Vec<(LocatedLink, String)>)>,
}Expand description
Exact text changes required for backlink rewrites during a note rename.
Fields
new_path: PathBufnew_stem: Stringid_will_update: boolbacklink_edits: Vec<(PathBuf, Vec<(LocatedLink, String)>)>Notes with backlinks that would be rewritten, sorted by path.