SearchQuery

Struct SearchQuery 

pub struct SearchQuery<'a> { /* private fields */ }
A composable query for filtering notes in a vault.

Filter semantics

Implementations

Source

impl SearchQuery<'static>

pub fn new(root: impl AsRef<Path>) -> Self

pub fn with_loaded_notes<'a>( self, notes: &'a HashMap<PathBuf, Note>, ) -> SearchQuery<'a>

Provide in-memory notes to use instead of their on-disk counterparts.

Each note’s note.path is matched against the vault’s note paths on disk. Notes whose paths exist on disk shadow the disk version; notes with no on-disk counterpart are included as additional candidates. In-memory notes are assumed to have content populated whenever content filters (e.g. and_content_contains) are used.

Source

impl<'a> SearchQuery<'a>

pub fn and_glob(self, pattern: impl Into<String>) -> Self

Note path must match this glob pattern (matched against the note’s path relative to the vault root).

pub fn or_glob(self, pattern: impl Into<String>) -> Self

Note path could match this glob pattern (matched against the note’s path relative to the vault root).

pub fn and_has_id(self, id: impl Into<String>) -> Self

Note must have this ID (case-sensitive by default).

pub fn or_has_id(self, id: impl Into<String>) -> Self

Note could have this ID (case-sensitive by default).

pub fn and_has_tag(self, tag: impl Into<String>) -> Self

Note must have this tag (case-insensitive by default).

pub fn or_has_tag(self, tag: impl Into<String>) -> Self

Note could have this tag (case-insensitive by default).

pub fn and_title_contains(self, s: impl Into<String>) -> Self

Must title must contain this substring (smart case-sensitive by default).

pub fn or_title_contains(self, s: impl Into<String>) -> Self

Must title could contain this substring (smart case-sensitive by default).

pub fn and_has_alias(self, alias: impl Into<String>) -> Self

Note must have this alias (smart case-sensitive by default).

pub fn or_has_alias(self, alias: impl Into<String>) -> Self

Note could have this alias (smart case-sensitive by default).

pub fn and_alias_contains(self, s: impl Into<String>) -> Self

Substring must match against any of the note’s aliases (smart case-sensitive by default).

pub fn or_alias_contains(self, s: impl Into<String>) -> Self

Substring could match against any of the note’s aliases (smart case-sensitive by default).

pub fn and_content_contains(self, s: impl Into<String>) -> Self

Note body must contain this string (smart case-sensitive by default).

pub fn or_content_contains(self, s: impl Into<String>) -> Self

Note body could contain this string (smart case-sensitive by default).

pub fn and_content_matches(self, pattern: impl Into<String>) -> Self

Regex body must match this pattern (smart case-sensitive by default).

pub fn or_content_matches(self, pattern: impl Into<String>) -> Self

Regex body could match this pattern (smart case-sensitive by default).

Has a link to this note

May link to this note

pub fn case_sensitive(self) -> Self

Execute the search case-sensitively.

pub fn ignore_case(self) -> Self

Execute the search case-insensitively.

pub fn smart_case(self) -> Self

Execute the search with smart case sensitivity: case-sensitive if the query contains any uppercase letters, otherwise case-insensitive.

pub fn include_inline_tags(self) -> Self

pub fn sort_by(self, sort_order: SortOrder) -> Self

pub fn execute(self) -> Result<Vec<Result<Note, NoteError>>, SearchError>

Execute the query, returning matching notes.

Returns Err if any glob or regex pattern is invalid. Each inner Err represents an I/O failure loading a specific note.